/*************************************

** OBJECTIVE **

Create weights in eq's (A-2) and (A-3) of the paper

- (A-3)=> U_rm = "Share of retail industry r's revenue attributed to manufacturing industry m"
- (A-4)=> S_jr = "Share of manufacturing indutry j's revenue derived from retail channel r"
- Weights are computed for manufacturing only, and for combined manufacturing/wholesale 


** INPUT FILES **

- CRT77_old.dta: Digitized version of 1977 Census of Retail Trade aggregate stats (see CRT1977-lines.pdf)
- crt-sic-xwalk-long-update.dta: Hand built concordance of CRT lines to SIC codes
- 1977RetailSIC_old.dta: 1-to-many mapping of CRT retail "Kind of Business" codes to 1977 retiler SIC codes 
- This code also uses the "mmerge" command, which is not pre-installed 

** PROCESS **

Step 1: Take crosswalk data and create a map between Upstream SIC and line codes
	
Step 2: Clean 1977 CRT data and Collapse to Broad-Line Retail-SIC level
	Remove omitted entries from CRT
	remove extra Broadcodes
	Merge retail SIC and collapse
	
Step 3: Create the Weight and Share Variables
	Sales: Total sales of a given line through a retail channel
	Share: Share of given line through a retail channel
	Divide both by number of industries in that channel
	Sum over L(j) to create equations (A-2) & (A-3)
	
*************************************/

** Set to path name of directory holding input files
global path "."

capture log close
log using "$path/makeweights.log", replace text

************
** Step 1 **
************

use "$path/crt-sic-xwalk-long.dta", clear
*levelsof LineCode, local(linecodelevel)
*drop if Year != 1977 //work with 1977 data for now
drop if BroadCode == . | BroadCode == 0 // remove missing broadlines
contract SIC BroadCode
drop _freq
drop if SIC == 0
save "$path/xwalk_new.dta", replace


************
** Step 2 **
************

* Note: CRT data contains a seperate kind of business catagory. This is mapped to the SIC retail channels with a SIC Code
use "$path/CRT77.dta", clear

*RTL77ML is CRT Broad Line
*RTL77KB is kind of business, numbered in order in appearence 
rename RTL77ML BroadCode
drop if strlen(RTL77KB) != 3
drop if ST != "00" //only use observations for entire United States
drop if (ESTAB == 0 | ESTAB == .) //remove missing entries
drop if (SALES == 0 | SALES == .)
destring(RTL77KB), replace
destring(BroadCode), replace
drop if RTL77KB > 105 //CRT only goes up to 105

/* Removing excluded lines */
drop if BroadCode == 120  //Meals and Snacks
drop if BroadCode == 130 //Alcoholic Drinks
drop if BroadCode == 720 //Automative fuel
drop if BroadCode == 780 //Household fuels
drop if BroadCode == 900 //Nonmerchandise recipts 

drop if RTL77KB == 1 // remove aggregate retail sales
drop SMSA ESTABF SALESF SALSPERF //Remove extra variables


/* Merge to Retail SIC Codes */
*Note: RTL77KB to SIC may change for different years
*All SIC codes are recorded in 4 digit format
*2 Digit SIC codes represent aggregates  
*Businesses with multiple SIC codes are listed as compound (52115231)
*The largest compound SIC is 16 digits, 4 SIC codes

merge m:1 RTL77KB using "$path/1977RetailSIC.dta", keep(match) nogen
destring retailSIC, gen(tmp) 
drop if tmp < 1000 //remove major group aggregates for SIC (eg: 52, 53)
drop RTL77KB tmp

* Some Retail SICs have multiple RTL77KB, so collapse
collapse (sum) SALES, by(BroadCode retailSIC) 


************
** Step 3 **
************

bys retailSIC: egen totalChannelSales = sum(SALES)
bys retailSIC BroadCode: egen totalLineSales = sum(SALES) // this should just equal SALES
gen lineChannelShare = totalLineSales/totalChannelSales //share of CRT line in a retail channel

/* Many-to-many merge through Broad Codes */
* xwalk_new is a contracted list of SIC/BroadCode pairs. 
* Note merge m:m does not create a complete pairwise merge!!
mmerge BroadCode using "$path/xwalk_new.dta", type(n:n) unmatched(none)
drop _merge

* Create N_c component of eqn (2) and (3)
bys BroadCode (SIC): egen ncAll = sum(SIC!=SIC[_n-1])
bys BroadCode (SIC): egen ncM = sum(SIC!=SIC[_n-1] & SIC<4000)

* Create summands of eqn (2) and (3)
gen shareOverNAll = lineChannelShare/ncAll //All SIC
gen shareOverNM = lineChannelShare/ncM //Manufacturing SIC
gen salesOverNAll = totalLineSales/ncAll //All SIC
gen salesOverNM = totalLineSales/ncM //Manufacturing SIC

* Check that all shares are in [0,1]
sum shareOverNAll shareOverNM, d


/* Creating Equation 4 */
bys retailSIC SIC: egen weightAll = sum(shareOverNAll)
by retailSIC SIC: egen weightM = sum(shareOverNM)

/* Creating Revenue piece of eq (2) */ 

bys SIC retailSIC: egen revenueAll = sum(salesOverNAll)
by SIC retailSIC: egen revenueM = sum(salesOverNM) 

* Remove duplicates 
* NOTE: dups occur when an SIC is sold in two Broad Codes in same channel
* Implication: Some Broad codes are missing even though I keep that variable in the data
bys SIC retailSIC: gen nvals = _n == 1
drop if nvals == 0
drop nvals

/* Creating Equation 2 */
bys SIC: egen revenueTotalAll = sum(revenueAll) // total sales for manufacturer across all retail SIC
by SIC: egen revenueTotalM = sum(revenueM)
gen shareM = revenueM/revenueTotalM
gen shareAll = revenueAll/revenueTotalAll


/* Cleanup */
keep BroadCode retailSIC SIC weightAll weightM shareAll shareM
order BroadCode retailSIC SIC weightAll weightM shareAll shareM

rename SIC manufSIC
rename weightM U_rm
rename weightAll U_rm_all
rename shareM S_mr
rename shareAll S_mr_all

label var U_rm "Eqn A-3 weight: manufacturing only"
label var U_rm_all "Eqn A-3 weight: manufacturing and wholesale"
label var S_mr "Eqn A-4 weight: manufacturing only"
label var U_rm_all "Eqn A-4 weight: manufacturing and wholesale"

save "$path/finalWeights.dta", replace



/* Check that Weights Sum to 1 */
bys retailSIC: egen checkw = sum(U_rm_all)
sum checkw, d

bys manufSIC: egen checks = sum(S_mr_all)
sum checks, d

corr U_rm_all U_rm S_mr_all S_mr

log close
